# Fitting a line with `abeec`
-----------------------------

The `line_example.py` script fits a line to the data stored in the `line_data.dat` file using `abeec`, and plots a corner plot of the results. 
The data was generated using the `line_utils.gen_fake_data()` function in the `line_utils.py` file. 
